@@ -8,20 +8,12 @@ def convert(num):
 class Country:
 	def __init__(self, country):
 		self.country = country
-		if self.country.lower() == "world":
-			global url
-			url = f"https://disease.sh/v2/all"
-			global qq
-			qq = requests.get(url)
-			global data
-			data = qq.json()
-		else:
-			global url
-			url = f"https://disease.sh/v2/countries/{self.country}"
-			global qq
-			qq = requests.get(url)
-			global data
-			data = qq.json()
+		global url
+		url = f"https://disease.sh/v2/countries/{self.country}"
+		global qq
+		qq = requests.get(url)
+		global data
+		data = qq.json()
 	def total_cases(self):
 		global data
 		cases = convert(int(data["cases"]))
